//
//  BannerViewController.swift
//  TAMTutorial
//
//  Created by Jimmy Shih on 2021/7/8.
//  Copyright © 2021 TAMedia. All rights reserved.
//

import UIKit
import TAMediaAdsFramework

@objc enum BannerType: Int {
    case BannerDefault
    case Banner320x250
    case Banner1200x627
    case SmartBanner
}

@objcMembers
class BannerViewController: UIViewController {
    @IBOutlet weak var resultLabel: UILabel!
    var banner: TADBannerView?
    var bannerType: BannerType = .Banner320x250

    deinit {
        print(#function)
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        requestAd()
    }

    func requestAd() {
        self.resultLabel.text = "Loading..."

        let request = TADRequest()
        request.showLog = true
        request.setLocationWithLatitude(25.02246916213678, longitude: 121.54834205241194, accuracy: 1)
        if bannerType == .BannerDefault {
            banner = TADBannerView.init(adSize: kTADAdSizeBanner, origin: CGPoint(x: 10, y: self.view.frame.size.height - 100))
            banner?.adUnitID = Constants.BannerAd320x50SlotID
        } else if bannerType == .Banner320x250 {
            banner = TADBannerView.init(adSize: kTADAdSizeMediumRectangle, origin: CGPoint(x: 10, y: self.view.frame.size.height - 300))
            banner?.adUnitID = Constants.BannerAd320x250SlotID
        } else if bannerType == .Banner1200x627 {
            banner = TADBannerView.init(adSize:  TADAdSize1200x627RatioBannerWithWidth(300), origin: CGPoint(x: 10, y: self.view.frame.size.height - 450))
            banner?.adUnitID = Constants.BannerAd1200x627SlotID
        } else if bannerType == .SmartBanner {
            banner = TADBannerView.init(adSize:  kTADAdSizeSmartBannerPortrait, origin: CGPoint(x: 0, y: self.view.frame.size.height - 100))
            banner?.adUnitID = Constants.BannerAd320x50SlotID
        }

        banner?.delegate = self
        banner?.rootViewController = self
        banner?.turnOnMicrophone = false
        banner?.load(request)
    }

    @IBAction func backButtonPressed(_ sender: UIButton) {
        self.dismiss(animated: true, completion: nil)
    }
}

extension BannerViewController: TADBannerViewDelegate {
    // 廣告取得成功
    func adViewDidReceiveAd(_ view: TADBannerView!) {
        self.resultLabel.text = "AD received"
    }

    // 廣告取得失敗
    func adView(_ view: TADBannerView!, didFailToReceiveAdWithError error: TADRequestError!) {
        print("Error:\(error.localizedDescription)")
        self.resultLabel.text = "Error:\(error.localizedDescription)"
    }

    // 廣告即將被呈現之前被呼叫
    func adViewWillPresentScreen(_ adView: TADBannerView!) {
        print(#function)
    }

    // 廣告即將被關閉之前被呼叫
    func adViewWillDismissScreen(_ adView: TADBannerView!) {
        print(#function)
    }

    // 廣告被關閉之後被呼叫
    func adViewDidDismissScreen(_ adView: TADBannerView!) {
        print(#function)
    }

    // 應用程式即將進入背景執行或中止運作前被呼叫
    func adViewWillLeaveApplication(_ adView: TADBannerView!) {
        print(#function)
    }

}
