//
//  InterstitialViewController.swift
//  TAMTutorial
//
//  Created by Jimmy Shih on 2021/7/8.
//  Copyright © 2021 TAMedia. All rights reserved.
//

import UIKit
import TAMediaAdsFramework

class InterstitialViewController: UIViewController {

    @IBOutlet weak var resultLabel: UILabel!
    var interstitialView: TADInterstitial?

    deinit {
        print(#function)
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        requestAd()
    }

    func requestAd() {
        self.resultLabel.text = "Loading..."

        let request = TADRequest()
        request.setLocationWithLatitude(25.02246916213678, longitude: 121.54834205241194, accuracy: 1)
        request.showLog = true
        interstitialView = TADInterstitial()
        interstitialView?.delegate = self
        interstitialView?.turnOnMicrophone = false
        interstitialView?.allowAudioSessionControl = true
        interstitialView?.adUnitID = Constants.InterstitialAdSlotID
        interstitialView?.load(request)
    }

    @IBAction func backButtonPressed(_ sender: UIButton) {
        self.dismiss(animated: true, completion: nil)
    }

}

extension InterstitialViewController: TADInterstitialDelegate {
    // 廣告取得成功，可以在此時間點及之後顯示呈現廣告
    func interstitialDidReceiveAd(_ ad: TADInterstitial!) {
        self.resultLabel.text = "Receive AD"
        ad.present(fromRootViewController: self)
    }

    // 廣告取得失敗
    func interstitial(_ ad: TADInterstitial!, didFailToReceiveAdWithError error: TADRequestError!) {
        self.resultLabel.text = "Error:\(error.description)"
    }

    // Interstitial廣告呈現之前呼叫, 注意使用者可能會在廣告內按下連結(網頁, AppStore, ...)而因此離開應用程式, 可以在這function中處理該暫停之項目
    func interstitialWillPresentScreen(_ ad: TADInterstitial!) {
        print(#function)
    }

    // Interstitial廣告關閉, 在螢幕上消失之前呼叫, 再次提醒在Interstitail消失前, 必須將Interstitial及delegate設為nil (可以在這個function中執行)
    func interstitialWillDismissScreen(_ ad: TADInterstitial!) {
        print(#function)
        self.interstitialView?.delegate = nil;
        self.interstitialView = nil;
    }

    // Interstitial廣告關閉, 在螢幕上消失之後呼叫
    func interstitialDidDismissScreen(_ ad: TADInterstitial!) {
        print(#function)
    }

    // 使用者在廣告內按下連結(網頁, AppStore, ...)而因此離開應用程式之前呼叫
    func interstitialWillLeaveApplication(_ ad: TADInterstitial!) {
        print(#function)
    }
}
