//
//  MainViewController.swift
//  TAMTutorial
//
//  Created by Jimmy Shih on 2021/7/8.
//  Copyright © 2021 TAMedia. All rights reserved.
//

import UIKit
enum AdOptions: String, CaseIterable {
    case BannerDefault = "Banner default"
    case Banner320x250 = "Banner 320x250"
    case Banner1200x627 = "Banner 1200x627"
    case SmartBanner = "SmartBanner"
    case Interstitial = "Interstitial"
    case Anchor = "Anchor"
    case NativeAd = "NativeAd"
    case NativeAdList = "NativeAdList"

    static var list: [String] {
        return AdOptions.allCases.map { $0.rawValue }
      }
}

class MainViewController: UIViewController {

    var adOptions: [String] = AdOptions.list
    
    override func viewDidLoad() {
        super.viewDidLoad()

        setupButtons()
    }

    func setupButtons() {
        let stackViewV = UIStackView(frame: UIScreen.main.bounds)
        stackViewV.alignment = .fill
        stackViewV.axis = .vertical
        stackViewV.spacing = 10
        stackViewV.distribution = .fillEqually
        view.addSubview(stackViewV)
        stackViewV.translatesAutoresizingMaskIntoConstraints = false
        stackViewV.leadingAnchor.constraint(equalTo: view.layoutMarginsGuide.leadingAnchor, constant: 10).isActive = true
        stackViewV.trailingAnchor.constraint(equalTo: view.layoutMarginsGuide.trailingAnchor, constant: -10).isActive = true
        stackViewV.topAnchor.constraint(equalTo: view.layoutMarginsGuide.topAnchor, constant: 20).isActive = true
        stackViewV.bottomAnchor.constraint(equalTo: view.layoutMarginsGuide.bottomAnchor, constant: -20).isActive = true


        for i in 0..<adOptions.count {
            let button = UIButton()
            button.tag = i
            button.backgroundColor = UIColor(red: 126/255, green: 104/255, blue: 202/255, alpha: 1)
            button.setTitle(adOptions[i], for: .normal)
            button.layer.cornerRadius = 10
            button.layer.borderColor = UIColor.white.cgColor
            button.layer.borderWidth = 3
            button.addTarget(self, action: #selector(buttonClick(sender:)), for: .touchUpInside)

            stackViewV.addArrangedSubview(button)
        }

        let versionNumber = Bundle.main.object(forInfoDictionaryKey: "CFBundleShortVersionString") as! String
        let buildNumber = Bundle.main.object(forInfoDictionaryKey: "CFBundleVersion") as! String
        let versionLabel = UILabel()
        versionLabel.translatesAutoresizingMaskIntoConstraints = false
        versionLabel.textAlignment = .center
        versionLabel.text = "TAMTutorial \(versionNumber)(\(buildNumber))"
        view.addSubview(versionLabel)
        versionLabel.bottomAnchor.constraint(equalTo: view.bottomAnchor, constant: -20).isActive = true
        versionLabel.centerXAnchor.constraint(equalTo: view.centerXAnchor).isActive = true

    }

    @objc func buttonClick(sender: UIButton) {
        var vcId: String = ""
        let adName = adOptions[sender.tag]
        var vc: UIViewController?
        switch adName {
        case AdOptions.BannerDefault.rawValue, AdOptions.Banner320x250.rawValue, AdOptions.Banner1200x627.rawValue, AdOptions.SmartBanner.rawValue:
            vcId = "BannerViewController";
            vc = UIStoryboard(name: "Main", bundle: nil).instantiateViewController(withIdentifier: vcId)
            if let vc = vc as? BannerViewController {                
                if adName == AdOptions.BannerDefault.rawValue {
                    vc.bannerType = .BannerDefault
                } else if adName == AdOptions.Banner320x250.rawValue {
                    vc.bannerType = .Banner320x250
                } else if adName == AdOptions.Banner1200x627.rawValue {
                    vc.bannerType = .Banner1200x627
                } else if adName == AdOptions.SmartBanner.rawValue {
                    vc.bannerType = .SmartBanner
                }
            }
            break;
        case AdOptions.Interstitial.rawValue:
            vcId = "InterstitialViewController"
            break;
        case AdOptions.Anchor.rawValue:
            vcId = "AnchorViewController"
            break;
        case AdOptions.NativeAd.rawValue:
            vcId = "NativeAdViewController"
            break;
        case AdOptions.NativeAdList.rawValue:
            vcId = "NativeAdListViewController"
            break;
        default:
            break;
        }

        if (vc == nil) {
            vc = UIStoryboard(name: "Main", bundle: nil).instantiateViewController(withIdentifier: vcId)
        }
        vc?.modalPresentationStyle = .fullScreen
        self.present(vc!, animated: true, completion: nil)
    }
}
