//
//  NativeAdListViewController.swift
//  TAMTutorial
//
//  Created by Jimmy Shih on 2021/7/8.
//  Copyright © 2021 TAMedia. All rights reserved.
//

import UIKit
import TAMediaAdsFramework

class NativeAdListViewController: UIViewController {
    @IBOutlet weak var resultLabel: UILabel!
    @IBOutlet weak var adTableView: UITableView!
    var nativeAd: TADNativeAd?
    var adArray: [Any] = ["1", "2", "1", "2", "1", "2", "1", "2"]

    deinit {
        print(#function)
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        requestAd()
        adTableView.register(
          UITableViewCell.self, forCellReuseIdentifier: "Cell")
        adTableView.register(UINib(nibName: "NativeAdCell", bundle: nil), forCellReuseIdentifier: "NativeAdCell")
    }

    func requestAd() {
        self.resultLabel.text = "Loading..."
        
        let request = TADRequest()
        nativeAd = TADNativeAd(adUnitId: Constants.NativeAdSlotID)
        nativeAd?.delegate = self
        nativeAd?.load(request)
    }

    func setupNativeAdView(ad: TADNativeAd, with cell: NativeAdCell) {
        let adView: TADNativeAdView = cell.nativeAdView
        
        adView.longSubjectLabel?.text = ad.adContent.longSubject
        adView.shortSubjectLabel?.text = ad.adContent.shortSubject
        adView.bodyLabel?.text = ad.adContent.body
        adView.squareImgeView?.image = ad.adContent.iconSquare?.image
        adView.rectangleImgeView?.image = ad.adContent.iconSquare?.image
        (adView.callToActionView as? UILabel)?.text = ad.adContent.callToAction
        adView.mediaView?.setMainImage(image: ad.adContent.mediaContent?.image960x640?.image)
        adView.mediaView?.setMainImage(contentMode: .scaleAspectFit)
        adView.mediaView?.mediaContent = ad.adContent.mediaContent
        adView.nativeAd = ad
    }

    @IBAction func backButtonPressed(_ sender: UIButton) {
        self.dismiss(animated: true, completion: nil)
    }

}

extension NativeAdListViewController: TADNativeAdDelegate {
    // 廣告取得成功
    func nativeAdDidReceive(_ ad: TADNativeAd!) {
        self.resultLabel.text = "Received AD"
        adArray.insert(ad!, at: 5)
        adTableView.reloadData()
    }

    // 廣告取得失敗
    func nativeAd(_ ad: TADNativeAd!, didFailToReceiveAdWithError error: TADRequestError!) {
        self.resultLabel.text = "Error:\(error.localizedDescription)"
    }

    // 廣告已有效曝光
    func nativeAdDidImpression(_ ad: TADNativeAd!) {
        print(#function)
    }

    // 點擊廣告
    func nativeAdDidClick(_ ad: TADNativeAd!) {
        print(#function)
    }
    
    // 應用程式即將進入背景執行或中止運作前被呼叫
    func nativeAdWillLeaveApplication(_ ad: TADNativeAd!) {
        print(#function)
    }
}

extension NativeAdListViewController: UITableViewDelegate, UITableViewDataSource {
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return adArray.count
    }

    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        var cell: UITableViewCell
        if let ad = adArray[indexPath.row] as? TADNativeAd {
            cell = tableView.dequeueReusableCell(
                withIdentifier: "NativeAdCell", for: indexPath) as!
                    NativeAdCell
            setupNativeAdView(ad: ad, with: cell as! NativeAdCell)
        } else {
            cell = tableView.dequeueReusableCell(
                        withIdentifier: "Cell", for: indexPath) as
                    UITableViewCell
            cell.textLabel?.text = adArray[indexPath.row] as? String
        }

        return cell
    }

    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return adArray[indexPath.row] is TADNativeAd ? 300 : 44
    }
}
