//
//  NativeAdListViewController.swift
//  NativeAdListViewController
//
//  Created by Kerry Dong on 2021/8/19.
//  Copyright © 2021 TAMedia. All rights reserved.
//

import UIKit
import TAMediaAdsFramework

class NativeAdViewController: UIViewController {
    @IBOutlet weak var resultLabel: UILabel!
    var nativeAd: TADNativeAd?
    var nativeAdView: TADNativeAdView?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        requestAd()
    }
    
    private func requestAd() {
        clearAd()
        self.resultLabel.text = "Loading..."
        
        let request = TADRequest()
        nativeAd = TADNativeAd(adUnitId: Constants.NativeAdSlotID)
        nativeAd?.delegate = self
        nativeAd?.load(request)
    }
    
    private func clearAd() {
        if nativeAd != nil {
            nativeAd?.delegate = nil
            nativeAd = nil
        }
    }
    
    private func setupNativeAdView(ad: TADNativeAd) {
        // 如果是用 addSubview 的方式加入 nativeAdView, 則先移除掉之前加的 view
        nativeAdView?.removeFromSuperview()
        // 使用 loadNib 引入 TADNativeAdView, 並從裡面取得 TADNativeMediaView
        guard let adView: TADNativeAdView = Bundle.main.loadNibNamed("TestNativeAdView", owner: nil, options: nil)?.first as? TADNativeAdView, let mediaView = adView.mediaView else {
            return
        }
        // 從原生廣告物件取得文字, 填入畫面裡的 UILabel
        adView.longSubjectLabel?.text = ad.adContent.longSubject
        adView.shortSubjectLabel?.text = ad.adContent.shortSubject
        adView.bodyLabel?.text = ad.adContent.body
        // 從原生廣告物件取得圖片, 填入畫面裡的 UIImageView
        adView.squareImgeView?.image = ad.adContent.iconSquare?.image
        adView.rectangleImgeView?.image = ad.adContent.iconSquare?.image
        // 從原生廣告物件取得外開廣告網頁的文字, 填入畫面裡的 UIView (可以為 UILabel/UIButton等..)
        (adView.callToActionView as? UILabel)?.text = ad.adContent.callToAction
        // 使用 UIImage 設定 media view 裡的 main image
        mediaView.setMainImage(image: ad.adContent.mediaContent?.image1200x627?.image)
        
        // 設定 main image 的圖片顯示方式
        mediaView.setMainImage(contentMode: .scaleAspectFit)
        // 從原生廣告物件取得 media content, 填入 media view, 由 media content 內部決定該顯示圖片或影音廣告
        mediaView.mediaContent = ad.adContent.mediaContent
        // 關聯 native ad view 與 native ad 物件, 設定後廣告才可以正常作用
        adView.nativeAd = ad
        
        // 將原生廣告加到畫面上
        adView.center = CGPoint(x: self.view.center.x, y: self.view.center.y)
        nativeAdView = adView
        self.view.addSubview(adView)
    }
}

extension NativeAdViewController: TADNativeAdDelegate {
    // 廣告取得成功
    func nativeAdDidReceive(_ ad: TADNativeAd!) {
        self.resultLabel.text = "Received AD"
        setupNativeAdView(ad: ad)
    }
    
    // 廣告取得失敗
    func nativeAd(_ ad: TADNativeAd!, didFailToReceiveAdWithError error: TADRequestError!) {
        self.resultLabel.text = "Error:\(error.localizedDescription)"
    }
    
    // 廣告已有效曝光
    func nativeAdDidImpression(_ ad: TADNativeAd!) {
        print("nativeAdDidImpression")
    }
    
    // 點擊廣告
    func nativeAdDidClick(_ ad: TADNativeAd!) {
        print("nativeAdDidClick")
    }
    
    // 應用程式即將進入背景執行或中止運作前被呼叫
    func nativeAdWillLeaveApplication(_ ad: TADNativeAd!) {
        print("nativeAdWillLeaveApplication")
    }
}


// MARK: - IBOutlet Function
extension NativeAdViewController {
    @IBAction func backButtonPressed(_ sender: UIButton) {
        self.dismiss(animated: true, completion: nil)
    }
}
